pytilities.test.mangling

Package pytilities :: Package test :: Module mangling |
[hide private]
[frames] | no frames]

# Source Code for Module pytilities.test.mangling

     1  # Copyright (C) 2010 Tim Diels <limyreth@users.sourceforge.net>
     2  #
     3  # This file is part of pytilities.
     4  #
     5  # pytilities is free software: you can redistribute it and/or modify
     6  # it under the terms of the GNU General Public License as published by
     7  # the Free Software Foundation, either version 3 of the License, or
     8  # (at your option) any later version.
     9  #
    10  # pytilities is distributed in the hope that it will be useful,
    11  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    12  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    13  # GNU General Public License for more details.
    14  #
    15  # You should have received a copy of the GNU General Public License
    16  # along with pytilities.  If not, see <http://www.gnu.org/licenses/>.
    17  #
    18
    19  __docformat__ = 'reStructuredText'
    20
    21  import unittest
    22
    23  from pytilities import mangle
    24
    25 -class Testlet(object):
    26      pass
    27
    28 -class MainTestCase(unittest.TestCase):
    29 -    def test_main(self):
    30          self.assertEquals(mangle('Name', '_nochange'), '_nochange')
    31          self.assertEquals(mangle('Name', '__nochange__'), '__nochange__')
    32          self.assertEquals(mangle('Name', 'nochange'), 'nochange')
    33          self.assertEquals(mangle('Name', '__change'), '_Name__change')
    34
    35          t = Testlet()
    36          self.assertEquals(mangle(t, '_nochange'), '_nochange')
    37          self.assertEquals(mangle(t, '__nochange__'), '__nochange__')
    38          self.assertEquals(mangle(t, 'nochange'), 'nochange')
    39          self.assertEquals(mangle(t, '__change'), '_Testlet__change')
    40